@@ -191,17 +191,24 @@ def get_lst_url_by_date(lst_device_id):
 
 def test_it_download():
     target_directory = './data/topic_download/'
-    int_total = len(get_lst_url_50())
-    for int_progress, done_url in it_download(get_lst_url_50(), target_directory):
-        print_progress(done_url, int_progress, int_total)
+    int_total = len(get_lst_url_taipei_100())
+    for int_progress, done_url in it_download(get_lst_url_taipei_100(), target_directory):
+        # print_progress(done_url, int_progress, int_total)
+        pass
 
 
 def test_it_distinct():
     target_directory = './data/topic_distinct/'
-    int_total = len(get_lst_url_50())
+    int_total, lst_distinct_column = total_distinct()
+    for int_progress, done_url in it_distinct(get_lst_url_taipei_100(), target_directory, lst_distinct_column):
+        # print_progress(done_url, int_progress, int_total)
+        pass
+
+
+def total_distinct():
+    int_total = len(get_lst_url_taipei_100())
     lst_distinct_column = ['deviceId', 'localTime', 'sensorId']
-    for int_progress, done_url in it_distinct(get_lst_url_50(), target_directory, lst_distinct_column):
-        print_progress(done_url, int_progress, int_total)
+    return int_total, lst_distinct_column
 
 
 def print_progress(done_url, int_progress, int_total):
@@ -211,10 +218,9 @@ def print_progress(done_url, int_progress, int_total):
 
 def test_it_group():
     target_directory = './data/topic_group/'
-    int_total = len(get_lst_url_50())
-    lst_distinct_column = ['deviceId', 'localTime', 'sensorId']
+    int_total, lst_distinct_column = total_distinct()
     lst_group_by_column = ['deviceId', 'sensorId']
-    for int_progress, done_url in it_group(get_lst_url_50(), target_directory, lst_distinct_column,
+    for int_progress, done_url in it_group(get_lst_url_taipei_100(), target_directory, lst_distinct_column,
                                            lst_group_by_column):
         print_progress(done_url, int_progress, int_total)
 
@@ -236,7 +242,6 @@ if __name__ == '__main__':
     # t = time.time()
     # test_it_download()
     # log(f'test_it_download:{time.time() - t}')
-    #
 
     # t = time.time()
     # test_it_distinct()
